@@ -14,13 +14,15 @@ from pymatgen.io.vasp.outputs import Vasprun, Outcar
 from typing import Optional
 import warnings
 import glob
-
+import os
 from monty.serialization import loadfn
 from pathlib import Path
 
+module_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)))
 
 def _read_user_incar(fname):
-    fil = open(fname, 'r')
+    fpath = os.path.join(module_dir,'library',fname)
+    fil = open(fpath, 'r')
     lines = fil.readlines()
     incar = {}
     for line in lines:
@@ -30,6 +32,7 @@ def _read_user_incar(fname):
     return incar
 
 
+
 class MPRelaxSet2D(DictSet):
     """
     Implementation of VaspInputSet utilizing parameters in the public
